# ===============================================================================
# Copyright 2021 ross
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ===============================================================================

EDM_REQUIREMENTS = [
    "chaco",
    "certifi",
    "cython",
    "envisage",
    "future",
    "gitpython",
    "keyring",
    "jinja2",
    "lxml",
    "numpy",
    "pandas",
    "patsy",
    "pillow",
    "pip",
    "pyface",
    "pyparsing",
    "pyproj",
    "pymysql",
    "pyqt5",
    "pytables",
    "pyyaml",
    "pygments",
    "qt",
    "Reportlab",
    "requests",
    "scipy",
    "sqlalchemy",
    "traits",
    "xlrd",
    "xlsxwriter",
    "xlwt",
    "statsmodels",
    "utm",
]
# ============= EOF =============================================
